--
-- Made for MF 135
--
-- Made by:
-- Martin Schmidt
-- 25/01/10
--
-- Copyright (C) 

BackHydraulicSystem = {};

function BackHydraulicSystem.prerequisitesPresent(specializations)
    return SpecializationUtil.hasSpecialization(Motorized, specializations);
end;

function BackHydraulicSystem:load(xmlFile)
	
	self.upperHydralicArm = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backHydraulicSystem#upperHydralicArm"));
	self.lowerHydralicArm = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backHydraulicSystem#lowerHydralicArm"));
	
	
	self.connectingArm = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backHydraulicSystem#connectingArm"));
	self.lowerConnectingArmPoint = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.backHydraulicSystem#lowerConnectingArmPoint"));
	
	
	self.topArm = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.topArm#index"));
	self.slackTopArm = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.slackTopArm#index"));
	self.drawbar = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.drawbar#index"));
	self.swingingDrawbar = Utils.indexToObject(self.components, getXMLString(xmlFile, "vehicle.swingingDrawbar#index"));
	
	
	
	self.manualHydraulic = true;
	setVisibility(self.slackTopArm, true);
	setVisibility(self.topArm, false);
	setVisibility(self.swingingDrawbar, false);
	setVisibility(self.drawbar, false);
	
	local x, y, z = getRotation(self.lowerHydralicArm);
	self.hydraulicRotation = x;
end;


function BackHydraulicSystem:update(dt)
	if self:getIsActive() then
	
		if Input.isKeyPressed(Input.KEY_o) and self.hydraulicRotation < 0.55 then
			self.hydraulicRotation = self.hydraulicRotation + 0.01;
		end;
		if Input.isKeyPressed(Input.KEY_l) and self.hydraulicRotation > -0.4 then
			self.hydraulicRotation = self.hydraulicRotation - 0.01;
		end;
		
		if self.manualHydraulic then
			setRotation(self.lowerHydralicArm, self.hydraulicRotation, 0, 0);
		end;
	
		-- Rotates Upper arm
		local x, y, z = getRotation(self.lowerHydralicArm);
		setRotation(self.upperHydralicArm, x, y, z);	

		-- Rotates the connecting arm
		local x1, y1, z1 = getWorldTranslation(self.connectingArm);
		local x2, y2, z2 = getWorldTranslation(self.lowerConnectingArmPoint);
		x, y, z = worldDirectionToLocal(getParent(self.connectingArm), x2-x1, y2-y1, z2-z1);
		setDirection(self.connectingArm, x, y, z, 0, 0, 1);
			
	end;
end;



function BackHydraulicSystem:attachImplement(implement)
	
	local implementType = implement.object.attacherJoint.jointType;
	
	if implementType == Vehicle.JOINTTYPE_IMPLEMENT then
		self.manualHydraulic = false;
		setVisibility(self.topArm, true);
		setVisibility(self.slackTopArm, false);
	elseif implementType == Vehicle.JOINTTYPE_TRAILER then
		setVisibility(self.drawbar, true);
	
	elseif implementType == Vehicle.JOINTTYPE_TRAILERLOW then
		setVisibility(self.swingingDrawbar, true);
	end;
	
	
end;

function BackHydraulicSystem:detachImplement(implementIndex)

	self.manualHydraulic = true;
	setVisibility(self.slackTopArm, true);
	setVisibility(self.topArm, false);
	setVisibility(self.swingingDrawbar, false);
	setVisibility(self.drawbar, false);

end;



function BackHydraulicSystem:draw()
end;
function BackHydraulicSystem:delete()
end;
function BackHydraulicSystem:mouseEvent(posX, posY, isDown, isUp, button)
end;
function BackHydraulicSystem:keyEvent(unicode, sym, modifier, isDown)
end;